VoyagerInfoWindow class

Constructors

VoyagerInfoWindow({required Widget widget, required LatLng latLng, required Size size})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
latLng LatLng
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
widget Widget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited